summaryrefslogtreecommitdiffstats
path: root/source/WorldStorage/WSSAnvil.h
diff options
context:
space:
mode:
authormadmaxoft@gmail.com <madmaxoft@gmail.com@0a769ca7-a7f5-676a-18bf-c427514a06d6>2012-10-28 18:30:10 +0100
committermadmaxoft@gmail.com <madmaxoft@gmail.com@0a769ca7-a7f5-676a-18bf-c427514a06d6>2012-10-28 18:30:10 +0100
commit265c810079acd2b82062827824f3ff65d495aa94 (patch)
treef6911b2f347913f3de0a5cb640ce6813c3dc4906 /source/WorldStorage/WSSAnvil.h
parentAdded cWorld:SpawnMob(PosX, PosY, PosZ, EntityType) to Lua API (diff)
downloadcuberite-265c810079acd2b82062827824f3ff65d495aa94.tar
cuberite-265c810079acd2b82062827824f3ff65d495aa94.tar.gz
cuberite-265c810079acd2b82062827824f3ff65d495aa94.tar.bz2
cuberite-265c810079acd2b82062827824f3ff65d495aa94.tar.lz
cuberite-265c810079acd2b82062827824f3ff65d495aa94.tar.xz
cuberite-265c810079acd2b82062827824f3ff65d495aa94.tar.zst
cuberite-265c810079acd2b82062827824f3ff65d495aa94.zip
Diffstat (limited to 'source/WorldStorage/WSSAnvil.h')
-rw-r--r--source/WorldStorage/WSSAnvil.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/source/WorldStorage/WSSAnvil.h b/source/WorldStorage/WSSAnvil.h
index b0641b586..37c1f0b4e 100644
--- a/source/WorldStorage/WSSAnvil.h
+++ b/source/WorldStorage/WSSAnvil.h
@@ -99,7 +99,10 @@ protected:
/// Saves the chunk into NBT data using a_Writer; returns true on success
bool SaveChunkToNBT(const cChunkCoords & a_Chunk, cFastNBTWriter & a_Writer);
- /// Loads the chunk's biome map; returns a_BiomeMap if biomes present and valid, NULL otherwise
+ /// Loads the chunk's biome map from vanilla-format; returns a_BiomeMap if biomes present and valid, NULL otherwise
+ cChunkDef::BiomeMap * LoadVanillaBiomeMapFromNBT(cChunkDef::BiomeMap * a_BiomeMap, const cParsedNBT & a_NBT, int a_TagIdx);
+
+ /// Loads the chunk's biome map from MCS format; returns a_BiomeMap if biomes present and valid, NULL otherwise
cChunkDef::BiomeMap * LoadBiomeMapFromNBT(cChunkDef::BiomeMap * a_BiomeMap, const cParsedNBT & a_NBT, int a_TagIdx);
/// Loads the chunk's entities from NBT data (a_Tag is the Level\\Entities list tag; may be -1)